Alle Klassen und Schnittstellen

Klasse
Beschreibung
Base class of every command line.
Base converter using a list of patterns to find a suitable convert operation.
Bundles different argument-specific information.
Converts a fully qualified class name to an instance of that class by invoking its default constructor.
Describes a command-line option.
Options are created using the associated CmdArgOption.Builder.
Builder for a command-line option.
The builder guarantees the option it builds is valid.
At a minimum an option requires a name.
A class to parse the Java command-line and access arguments by name and type using CmdArgOptions.
A run-time exception to report a command-line parsing error or failure.
 
Default usage formatter used when no other formatter was specified
Converts a string to a Double object.
Converts a string to an Enum constant of the type specified in the constructor and the same case-insensitive name.
A run-time exception to report a invalid option value on a command with a list of possible options.
Interface which have to be implemented by any usage formatter.
Interface implemented by all value converters to convert a given String to the proper object type.
Converts a string to a LocalDate object.
Converts a string to a LocalDateTime object.
Converts a string to a LocalTime object.
Utility bundling re-used static methods.