Klasse CommandLineException

java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
com.github.hypfvieh.cli.parser.CommandLineException
Alle implementierten Schnittstellen:
Serializable
Bekannte direkte Unterklassen:
InvalidOptionValueException

public class CommandLineException extends RuntimeException
A run-time exception to report a command-line parsing error or failure.
Siehe auch:
  • Konstruktordetails

    • CommandLineException

      public CommandLineException(String _message)
      Constructs a new exception with the specified detail message.
      Parameter:
      _message - the detail message
    • CommandLineException

      public CommandLineException(String _message, Throwable _cause)
      Constructs a new exception with the specified detail message and cause.
      Parameter:
      _message - the detail message (which is saved for later retrieval by the Throwable.getMessage() method).
      _cause - the cause (which is saved for later retrieval by the Throwable.getCause() method).