Package com.github.hypfvieh.cli.parser
Klasse InvalidOptionValueException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
com.github.hypfvieh.cli.parser.CommandLineException
com.github.hypfvieh.cli.parser.InvalidOptionValueException
- Alle implementierten Schnittstellen:
Serializable
A run-time exception to report a invalid option value on a command with a list of possible options.
- Siehe auch:
-
Konstruktorübersicht
KonstruktorenKonstruktorBeschreibungInvalidOptionValueException(String _message) InvalidOptionValueException(String _message, Throwable _cause) -
Methodenübersicht
Von Klasse geerbte Methoden java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Konstruktordetails
-
InvalidOptionValueException
-
InvalidOptionValueException
-