Verwendungen von Klasse
com.github.hypfvieh.cli.parser.CmdArgOption
Packages, die CmdArgOption verwenden
-
Verwendungen von CmdArgOption in com.github.hypfvieh.cli.parser
Methoden in com.github.hypfvieh.cli.parser, die CmdArgOption zurückgebenModifizierer und TypMethodeBeschreibungCmdArgOption.Builder.build()Create the option object based on configuration.CmdArgOption<?> AbstractBaseCommandLine.getOption(CharSequence _optionName) Returns a option using its name.Methoden in com.github.hypfvieh.cli.parser, die Typen mit Argumenten vom Typ CmdArgOption zurückgebenModifizierer und TypMethodeBeschreibungMap<CmdArgOption<?>, String> AbstractBaseCommandLine.getDupArgs()Returns a unmodifiable Map of all parsed, known but duplicated arguments.Map<CmdArgOption<?>, String> AbstractBaseCommandLine.getKnownArgs()Returns a unmodifiable Map of all successfully parsed, known arguments.Map<String, CmdArgOption<?>> AbstractBaseCommandLine.getOptions()Returns a unmodifiable Map of all configured options.Methoden in com.github.hypfvieh.cli.parser mit Parametern vom Typ CmdArgOptionModifizierer und TypMethodeBeschreibungAbstractBaseCommandLine.addOption(CmdArgOption<?> _option) Add an option to the supported options.AbstractBaseCommandLine.addOptions(CmdArgOption<?>... _options) Adds multiple options to the supported options.static StringStaticUtils.formatOption(CmdArgOption<?> _arg, String _longOptPrefix, String _shortOptPrefix) Formats the given option for logging/exceptions.static StringStaticUtils.formatOption(CmdArgOption<?> _arg, String _longOptPrefix, String _shortOptPrefix, String _joiningDelimiter) Formats the given option for logging/exceptions.<T> TCommandLine.getArg(CmdArgOption<T> _option) Returns the value associated with argument option.<T> TCommandLine.getArg(CmdArgOption<T> _option, T _default) Returns the value associated with argument option.intCommandLine.getArgCount(CmdArgOption<?> _option) Returns the number of occurrences of the given option.<T> List<T> CommandLine.getArgs(CmdArgOption<T> _option) Returns the value associated with argument option.<T> List<T> CommandLine.getArgs(CmdArgOption<T> _option, T _default) Returns the value associated with argument option.booleanCommandLine.hasArg(CmdArgOption<?> _option) Checks if the given option was at least used once in the command line.booleanAbstractBaseCommandLine.hasOption(CmdArgOption<?> _option) Checks if the given option is already present.Methodenparameter in com.github.hypfvieh.cli.parser mit Typargumenten vom Typ CmdArgOptionModifizierer und TypMethodeBeschreibungprotected booleanAbstractBaseCommandLine.hasArg(Function<B, CmdArgOption<?>> _argFunction) Tries to find aCmdArgOptionusing the given function and checks if the option was used in the parsed command line. -
Verwendungen von CmdArgOption in com.github.hypfvieh.cli.parser.formatter
Methodenparameter in com.github.hypfvieh.cli.parser.formatter mit Typargumenten vom Typ CmdArgOptionModifizierer und TypMethodeBeschreibungDefaultHelpFormatter.format(List<CmdArgOption<?>> _options, String _longOptPrefix, String _shortOptPrefix, String _mainClassName) Formats the given options as proper help-text.DefaultUsageFormatter.format(List<CmdArgOption<?>> _options, String _longOptPrefix, String _shortOptPrefix, String _mainClassName) IUsageFormatter.format(List<CmdArgOption<?>> _options, String _longOptPrefix, String _shortOptPrefix, String _mainClassName) Called to retrieve a formatted usage output.