Verwendungen von Klasse
com.github.hypfvieh.cli.parser.CmdArgOption.Builder
Packages, die CmdArgOption.Builder verwenden
-
Verwendungen von CmdArgOption.Builder in com.github.hypfvieh.cli.parser
Methoden in com.github.hypfvieh.cli.parser, die CmdArgOption.Builder zurückgebenModifizierer und TypMethodeBeschreibungstatic CmdArgOption.Builder<Void> CmdArgOption.builder()Returns a builder for a new option without value (therefore default value not permitted).static <T> CmdArgOption.Builder<T> Returns a builder for a new option with the specified data type.
As the data type is specified, the option must have a value (and may have a default value).CmdArgOption.Builder.defaultValue(T _defaultValue) Sets the option's default value.CmdArgOption.Builder.description(String _description) Sets the option's description text.Sets option long name.CmdArgOption.Builder.optional()Sets option to be optional.CmdArgOption.Builder.possibleValue(Map<T, String> _possibleValues) Add predefined value and description allowed for this command option.CmdArgOption.Builder.repeatable()Sets option to be repeatable.CmdArgOption.Builder.repeatable(boolean _repeatable) Sets option to be repeatable (true) or not (false).CmdArgOption.Builder.required()Sets option to be required.CmdArgOption.Builder.required(boolean _required) Sets option to be required or optional.Sets option short name.