Package com.github.hypfvieh.cli.parser.converter
package com.github.hypfvieh.cli.parser.converter
-
KlasseBeschreibungBase converter using a list of patterns to find a suitable convert operation.Converts a fully qualified class name to an instance of that class by invoking its default constructor.Converts a string to a
Doubleobject.Converts a string to anEnumconstant of the type specified in the constructor and the same case-insensitive name.Interface implemented by all value converters to convert a given String to the proper object type.Converts a string to aLocalDateobject.Converts a string to aLocalDateTimeobject.Converts a string to aLocalTimeobject.