Package com.github.hypfvieh.cli.parser.formatter
package com.github.hypfvieh.cli.parser.formatter
-
KlasseBeschreibungDefault usage formatter used when no other formatter was specifiedInterface which have to be implemented by any usage formatter.