Package com.github.hypfvieh.cli.parser
package com.github.hypfvieh.cli.parser
-
KlasseBeschreibungAbstractBaseCommandLine<B extends AbstractBaseCommandLine<?>>Base class of every command line.Bundles different argument-specific information.CmdArgOption<T>Describes a command-line option.
Options are created using the associatedCmdArgOption.Builder.Builder for a command-line option.
The builder guarantees the option it builds is valid.
At a minimum an option requires a name.A class to parse the Java command-line and access arguments by name and type usingCmdArgOptions.A run-time exception to report a command-line parsing error or failure.A run-time exception to report a invalid option value on a command with a list of possible options.Utility bundling re-used static methods.