Verwendungen von Package
com.github.hypfvieh.cli.parser
Packages, die com.github.hypfvieh.cli.parser verwenden
-
Von com.github.hypfvieh.cli.parser verwendete Klassen in com.github.hypfvieh.cli.parserKlasseBeschreibungBase class of every command line.Describes a command-line option.
Options are created using the associatedCmdArgOption.Builder.Builder for a command-line option.
The builder guarantees the option it builds is valid.
At a minimum an option requires a name.A class to parse the Java command-line and access arguments by name and type usingCmdArgOptions.A run-time exception to report a command-line parsing error or failure. -
Von com.github.hypfvieh.cli.parser.formatter verwendete Klassen in com.github.hypfvieh.cli.parserKlasseBeschreibungDescribes a command-line option.
Options are created using the associatedCmdArgOption.Builder.