Index

A B C D E F G H I L N O P R S T W 
Alle Klassen und Schnittstellen|Alle Packages|Serialisierte Form

A

AbstractBaseCommandLine<B> - Klasse in com.github.hypfvieh.cli.parser
Base class of every command line.
AbstractBaseCommandLine() - Konstruktor für Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Default constructor with long prefix -- and short prefix -.
AbstractPatternBasedConverter<T,P> - Klasse in com.github.hypfvieh.cli.parser.converter
Base converter using a list of patterns to find a suitable convert operation.
AbstractPatternBasedConverter() - Konstruktor für Klasse com.github.hypfvieh.cli.parser.converter.AbstractPatternBasedConverter
 
addOption(CmdArgOption<?>) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Add an option to the supported options.
addOptions(CmdArgOption<?>...) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Adds multiple options to the supported options.
addPattern(P) - Methode in Klasse com.github.hypfvieh.cli.parser.converter.AbstractPatternBasedConverter
Adds a pattern.
ArgumentBundle - Klasse in com.github.hypfvieh.cli.parser
Bundles different argument-specific information.
ArgumentBundle() - Konstruktor für Klasse com.github.hypfvieh.cli.parser.ArgumentBundle
 

B

build() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption.Builder
Create the option object based on configuration.
builder() - Statische Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
Returns a builder for a new option without value (therefore default value not permitted).
builder(Class<T>) - Statische Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
Returns a builder for a new option with the specified data type.
As the data type is specified, the option must have a value (and may have a default value).

C

ClassNameToInstanceConverter<T> - Klasse in com.github.hypfvieh.cli.parser.converter
Converts a fully qualified class name to an instance of that class by invoking its default constructor.
ClassNameToInstanceConverter() - Konstruktor für Klasse com.github.hypfvieh.cli.parser.converter.ClassNameToInstanceConverter
 
CmdArgOption<T> - Klasse in com.github.hypfvieh.cli.parser
Describes a command-line option.
Options are created using the associated CmdArgOption.Builder.
CmdArgOption.Builder<T> - Klasse in com.github.hypfvieh.cli.parser
Builder for a command-line option.
The builder guarantees the option it builds is valid.
At a minimum an option requires a name.
com.github.hypfvieh.cli.parser - Package com.github.hypfvieh.cli.parser
 
com.github.hypfvieh.cli.parser.converter - Package com.github.hypfvieh.cli.parser.converter
 
com.github.hypfvieh.cli.parser.formatter - Package com.github.hypfvieh.cli.parser.formatter
 
CommandLine - Klasse in com.github.hypfvieh.cli.parser
A class to parse the Java command-line and access arguments by name and type using CmdArgOptions.
CommandLine() - Konstruktor für Klasse com.github.hypfvieh.cli.parser.CommandLine
 
CommandLineException - Ausnahmeklasse in com.github.hypfvieh.cli.parser
A run-time exception to report a command-line parsing error or failure.
CommandLineException(String) - Konstruktor für Ausnahmeklasse com.github.hypfvieh.cli.parser.CommandLineException
Constructs a new exception with the specified detail message.
CommandLineException(String, Throwable) - Konstruktor für Ausnahmeklasse com.github.hypfvieh.cli.parser.CommandLineException
Constructs a new exception with the specified detail message and cause.
convert(String) - Methode in Klasse com.github.hypfvieh.cli.parser.converter.ClassNameToInstanceConverter
 
convert(String) - Methode in Klasse com.github.hypfvieh.cli.parser.converter.DoubleConverter
 
convert(String) - Methode in Klasse com.github.hypfvieh.cli.parser.converter.EnumConverter
 
convert(String) - Methode in Schnittstelle com.github.hypfvieh.cli.parser.converter.IValueConverter
Called to convert command line argument String to specified type.
convert(String) - Methode in Klasse com.github.hypfvieh.cli.parser.converter.LocalDateConverter
 
convert(String) - Methode in Klasse com.github.hypfvieh.cli.parser.converter.LocalDateTimeConverter
 
convert(String) - Methode in Klasse com.github.hypfvieh.cli.parser.converter.LocalTimeConverter
 

D

DefaultHelpFormatter - Klasse in com.github.hypfvieh.cli.parser.formatter
 
DefaultHelpFormatter() - Konstruktor für Klasse com.github.hypfvieh.cli.parser.formatter.DefaultHelpFormatter
 
DefaultUsageFormatter - Klasse in com.github.hypfvieh.cli.parser.formatter
Default usage formatter used when no other formatter was specified
DefaultUsageFormatter() - Konstruktor für Klasse com.github.hypfvieh.cli.parser.formatter.DefaultUsageFormatter
 
defaultValue(T) - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption.Builder
Sets the option's default value.
description(String) - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption.Builder
Sets the option's description text.
DoubleConverter - Klasse in com.github.hypfvieh.cli.parser.converter
Converts a string to a Double object.
DoubleConverter() - Konstruktor für Klasse com.github.hypfvieh.cli.parser.converter.DoubleConverter
Default constructor for a double converter.

E

EnumConverter - Klasse in com.github.hypfvieh.cli.parser.converter
Converts a string to an Enum constant of the type specified in the constructor and the same case-insensitive name.
EnumConverter(Class<Enum<?>>) - Konstruktor für Klasse com.github.hypfvieh.cli.parser.converter.EnumConverter
 
equals(Object) - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
 

F

format(List<CmdArgOption<?>>, String, String, String) - Methode in Klasse com.github.hypfvieh.cli.parser.formatter.DefaultHelpFormatter
Formats the given options as proper help-text.
format(List<CmdArgOption<?>>, String, String, String) - Methode in Klasse com.github.hypfvieh.cli.parser.formatter.DefaultUsageFormatter
 
format(List<CmdArgOption<?>>, String, String, String) - Methode in Schnittstelle com.github.hypfvieh.cli.parser.formatter.IUsageFormatter
Called to retrieve a formatted usage output.
formatOption(CmdArgOption<?>, String, String) - Statische Methode in Klasse com.github.hypfvieh.cli.parser.StaticUtils
Formats the given option for logging/exceptions.
formatOption(CmdArgOption<?>, String, String, String) - Statische Methode in Klasse com.github.hypfvieh.cli.parser.StaticUtils
Formats the given option for logging/exceptions.

G

getArg(char) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Returns an option value using the options short name.
getArg(char, Class<T>) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Returns an option value using the options short name and converting the value to the given type.
getArg(char, Class<T>, T) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Returns an option value using the options short name and converting the value to the given type.
getArg(CmdArgOption<T>) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Returns the value associated with argument option.
getArg(CmdArgOption<T>, T) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Returns the value associated with argument option.
getArg(CharSequence) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Returns an option value using the options name.
getArg(CharSequence, Class<T>) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Returns an option value using the options name and converting the value to the given type.
getArg(CharSequence, Class<T>, T) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Returns an option value using the options name and converting the value to the given type.
getArgCount(CmdArgOption<?>) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Returns the number of occurrences of the given option.
getArgs(char, Class<T>) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Returns all option values using the options short name and converting the values to the given type.
getArgs(CmdArgOption<T>) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Returns the value associated with argument option.
getArgs(CmdArgOption<T>, T) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Returns the value associated with argument option.
getArgs(CharSequence, Class<T>) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Returns all option values using the options name and converting the values to the given type.
getArgumentHelp(String) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Creates a multiline String containing all options and descriptions configured.
getDataType() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
Returns the type of data to create from argument.
getDefaultValue() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
Returns the default value for this option (when option was not set).
getDescription() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
Returns the description text for this option.
getDupArgs() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns a unmodifiable Map of all parsed, known but duplicated arguments.
getExceptionType() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns the class of the current configured exception.
getKnownArgs() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns a unmodifiable Map of all successfully parsed, known arguments.
getLogger() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns the logger instance.
getLogger() - Methode in Klasse com.github.hypfvieh.cli.parser.converter.AbstractPatternBasedConverter
Access to the logger for subclass objects.
getLongOptPattern() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns the current pattern to parse long option names.
getLongOptPrefix() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns the current long option name prefix.
getMainClassName() - Statische Methode in Schnittstelle com.github.hypfvieh.cli.parser.formatter.IUsageFormatter
Returns the simple class name of the topmost stack element which is not in our own package.
getName() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
Returns the long name of this option
getOption(CharSequence) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns a option using its name.
getOptions() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns a unmodifiable Map of all configured options.
getPatterns() - Methode in Klasse com.github.hypfvieh.cli.parser.converter.AbstractPatternBasedConverter
Returns the list of patterns
getPossibleValues() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
A map containing all values (and description) allowed for this option.
getShortName() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
Returns the short name of this option.
getShortOptPattern() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns the current pattern to parse short option names.
getShortOptPrefix() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns the current short option name prefix.
getUnknownArgs() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns a unmodifiable Map of all parsed, but unknown arguments.
The value of the map will represent the parsed value, or null if no value found.
getUnknownTokens() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns a unmodifiable list of all unknown option arguments.
getUsage(String) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Creates the "usage" String using the configured formatter.

H

hasArg(char) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Checks if the given option was at least used once in the command line.
hasArg(CmdArgOption<?>) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Checks if the given option was at least used once in the command line.
hasArg(String) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Checks if the given option was at least used once in the command line.
hasArg(Function<B, CmdArgOption<?>>) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Tries to find a CmdArgOption using the given function and checks if the option was used in the parsed command line.
hashCode() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
 
hasOption(CmdArgOption<?>) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Checks if the given option is already present.
hasOption(CharSequence) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Checks if there is any option with the given name.
hasValue() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
Flag to signal if the option requires a value.

I

InvalidOptionValueException - Ausnahmeklasse in com.github.hypfvieh.cli.parser
A run-time exception to report a invalid option value on a command with a list of possible options.
InvalidOptionValueException(String) - Konstruktor für Ausnahmeklasse com.github.hypfvieh.cli.parser.InvalidOptionValueException
 
InvalidOptionValueException(String, Throwable) - Konstruktor für Ausnahmeklasse com.github.hypfvieh.cli.parser.InvalidOptionValueException
 
isFailOnDupArg() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns true when command line parsing fails on duplicated arguments.
isFailOnUnknownArg() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns true when command line parsing fails on unknown arguments.
isFailOnUnknownToken() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Returns true when command line parsing fails on unknown tokens.
isOptional() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
Flag to signal that this option is optional.
isParsed() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Signals if the command line has been parsed.
isRepeatable() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
Flag to allow the option to be repeated multiple times.
isRequired() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
Flag to signal if this option is required.
IUsageFormatter - Schnittstelle in com.github.hypfvieh.cli.parser.formatter
Interface which have to be implemented by any usage formatter.
IValueConverter<T> - Schnittstelle in com.github.hypfvieh.cli.parser.converter
Interface implemented by all value converters to convert a given String to the proper object type.

L

LocalDateConverter - Klasse in com.github.hypfvieh.cli.parser.converter
Converts a string to a LocalDate object.
LocalDateConverter() - Konstruktor für Klasse com.github.hypfvieh.cli.parser.converter.LocalDateConverter
Default constructor.
LocalDateTimeConverter - Klasse in com.github.hypfvieh.cli.parser.converter
Converts a string to a LocalDateTime object.
LocalDateTimeConverter() - Konstruktor für Klasse com.github.hypfvieh.cli.parser.converter.LocalDateTimeConverter
Default constructor.
LocalTimeConverter - Klasse in com.github.hypfvieh.cli.parser.converter
Converts a string to a LocalTime object.
LocalTimeConverter() - Konstruktor für Klasse com.github.hypfvieh.cli.parser.converter.LocalTimeConverter
Default constructor.
logResults() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Prints some debug statements to the configured logger.

N

name(String) - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption.Builder
Sets option long name.

O

optional() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption.Builder
Sets option to be optional.

P

parse(String[]) - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Parses the given arguments.
possibleValue(Map<T, String>) - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption.Builder
Add predefined value and description allowed for this command option.
printUsage() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Prints the "usage" of the program to stdout.
printUsage(String, OutputStream) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Prints the "usage" of the program to the given output.

R

registerConverter(Class<T>, IValueConverter<T>) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Registers a converter to convert an option argument String to a specific java object type.
repeatable() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption.Builder
Sets option to be repeatable.
repeatable(boolean) - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption.Builder
Sets option to be repeatable (true) or not (false).
required() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption.Builder
Sets option to be required.
required(boolean) - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption.Builder
Sets option to be required or optional.

S

self() - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
A reference to ourselves to allow chaining with subclasses.
self() - Methode in Klasse com.github.hypfvieh.cli.parser.CommandLine
Reference to ourselves for chaining.
setParsed(boolean) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Set the parsed state.
shortName(Character) - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption.Builder
Sets option short name.
StaticUtils - Klasse in com.github.hypfvieh.cli.parser
Utility bundling re-used static methods.

T

toString() - Methode in Klasse com.github.hypfvieh.cli.parser.CmdArgOption
 

W

withExceptionType(Class<? extends RuntimeException>) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Set a RuntimeException based exception class thrown when command line parsing fails.
withFailOnDupArg(boolean) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Specifies if command line parsing should fail when an duplicate argument was found.
withFailOnUnknownArg(boolean) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Specifies if command line parsing should fail when an unknown argument was found.
withFailOnUnknownToken(boolean) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Specifies if command line parsing should fail when an unknown token was found.
withHelpFormatter(IUsageFormatter) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Setup a different help formatter.
withLongOptPrefix(String) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Defines the prefix for long-option names.
withShortOptPrefix(String) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Defines the prefix for short-option names.
withUsageFormatter(IUsageFormatter) - Methode in Klasse com.github.hypfvieh.cli.parser.AbstractBaseCommandLine
Setup a different usage formatter.
A B C D E F G H I L N O P R S T W 
Alle Klassen und Schnittstellen|Alle Packages|Serialisierte Form