Package com.github.hypfvieh.cli.parser
Klasse CmdArgOption.Builder<T>
java.lang.Object
com.github.hypfvieh.cli.parser.CmdArgOption.Builder<T>
- Umschließende Klasse:
CmdArgOption<T>
Builder for a command-line option.
The builder guarantees the option it builds is valid.
At a minimum an option requires a name.
The builder guarantees the option it builds is valid.
At a minimum an option requires a name.
-
Methodenübersicht
Modifizierer und TypMethodeBeschreibungbuild()Create the option object based on configuration.defaultValue(T _defaultValue) Sets the option's default value.description(String _description) Sets the option's description text.Sets option long name.optional()Sets option to be optional.possibleValue(Map<T, String> _possibleValues) Add predefined value and description allowed for this command option.Sets option to be repeatable.repeatable(boolean _repeatable) Sets option to be repeatable (true) or not (false).required()Sets option to be required.required(boolean _required) Sets option to be required or optional.Sets option short name.
-
Methodendetails
-
name
Sets option long name.- Parameter:
_name- name- Gibt zurück:
- this
-
shortName
Sets option short name.- Parameter:
_name- name- Gibt zurück:
- this
-
required
Sets option to be required or optional.- Parameter:
_required- true to be required- Gibt zurück:
- this
-
required
Sets option to be required.- Gibt zurück:
- this
-
optional
Sets option to be optional.- Gibt zurück:
- this
-
repeatable
Sets option to be repeatable (true) or not (false).- Parameter:
_repeatable- true to be repeatable- Gibt zurück:
- this
-
repeatable
Sets option to be repeatable.- Gibt zurück:
- this
-
defaultValue
Sets the option's default value.- Parameter:
_defaultValue- value to use, never null- Gibt zurück:
- this
-
description
Sets the option's description text.- Parameter:
_description- text to use- Gibt zurück:
- this
-
possibleValue
Add predefined value and description allowed for this command option.
The used map implementation provided will define the value order and comparison.
If you use String as type and you want to allow case-insensitive value comparison
then use aTreeMapwithString.CASE_INSENSITIVE_ORDERcomparator.- Parameter:
_possibleValues- map with possible values and a description.- Gibt zurück:
- this
- Seit:
- 1.0.4 - 2023-05-12
-
build
Create the option object based on configuration.- Gibt zurück:
- CmdArgOption
-