Package com.github.hypfvieh.cli.parser
Klasse CommandLineException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
com.github.hypfvieh.cli.parser.CommandLineException
- Alle implementierten Schnittstellen:
Serializable
- Bekannte direkte Unterklassen:
InvalidOptionValueException
A run-time exception to report a command-line parsing error or failure.
- Siehe auch:
-
Konstruktorübersicht
KonstruktorenKonstruktorBeschreibungCommandLineException(String _message) Constructs a new exception with the specified detail message.CommandLineException(String _message, Throwable _cause) Constructs a new exception with the specified detail message and cause. -
Methodenübersicht
Von Klasse geerbte Methoden java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Konstruktordetails
-
CommandLineException
Constructs a new exception with the specified detail message.- Parameter:
_message- the detail message
-
CommandLineException
Constructs a new exception with the specified detail message and cause.- Parameter:
_message- the detail message (which is saved for later retrieval by theThrowable.getMessage()method)._cause- the cause (which is saved for later retrieval by theThrowable.getCause()method).
-