Schnittstelle IUsageFormatter
- Alle bekannten Implementierungsklassen:
DefaultHelpFormatter,DefaultUsageFormatter
- Funktionsschnittstelle:
- Dies ist eine funktionale Schnittstelle, die somit als Zuweisungsziel für einen Lambdaausdruck oder eine Methodenreferenz verwendet werden kann.
Interface which have to be implemented by any usage formatter.
- Seit:
- 1.0.0 - 2022-05-05
- Autor:
- David M., Markus S.
-
Methodenübersicht
Modifizierer und TypMethodeBeschreibungformat(List<CmdArgOption<?>> _options, String _longOptPrefix, String _shortOptPrefix, String _mainClassName) Called to retrieve a formatted usage output.static StringReturns the simple class name of the topmost stack element which is not in our own package.
-
Methodendetails
-
format
String format(List<CmdArgOption<?>> _options, String _longOptPrefix, String _shortOptPrefix, String _mainClassName) Called to retrieve a formatted usage output.Output should be properly formatted including line-feeds etc.
- Parameter:
_options- registered options, maybe empty - never null_longOptPrefix- prefix for long options_shortOptPrefix- prefix for short options_mainClassName- main class name, maybe null- Gibt zurück:
- formatted String
-
getMainClassName
Returns the simple class name of the topmost stack element which is not in our own package.- Gibt zurück:
- simple class name
-